@@ -3,7 +3,9 @@ import itertools
 
 import pytest
 
-from geco.mips.set_cover import *
+from geco.mips.set_cover.generic import *
+from geco.mips.set_cover.yang import *
+from geco.mips.set_cover.sun import *
 
 """
 Generic Tests
